@@ -11,11 +11,23 @@
 #ifndef __TIMING_HPP_
 #define __TIMING_HPP_
 
+#if (defined WIN32) && !(defined _WINDOWS_)
+// Rather than throw Windows.h into unrelated code, declare FILETIME as a
+// struct here
+typedef struct _FILETIME {
+    int32_t dwLowDateTime;
+    int32_t dwHighDateTime;
+} FILETIME;
+#endif
+
 class time_marker
 {
 public:
 #if defined __CELLOS_LV2__
     uint64_t ticks;
+#elif defined WIN32
+	// Use FILETIME
+	FILETIME ticks;
 #else
     long seconds;
     long micro_seconds;
@@ -26,4 +38,3 @@ public:
 };
 
 #endif
-
