@@ -14,24 +14,26 @@
 struct flags_struct
 {
     short fullscreen;
-    short doublebuf;
     short mono;
     short nosound;
     short grabmouse;
-    short nosdlparachute;
     short xres;
     short yres;
     short overlay;
-    short gl;
     int antialias;
+    int software;
 };
 
 struct keys_struct
 {
     int left;
+    int left_2;
     int right;
+    int right_2;
     int up;
+    int up_2;
     int down;
+    int down_2;
     int b1;
     int b2;
     int b3;
