@@ -12,7 +12,14 @@
 #   include "config.h"
 #endif
 
-#include <unistd.h>
+#ifdef HAVE_UNISTD_H
+# include <unistd.h>
+#endif
+#ifdef WIN32
+# include <Windows.h>
+// Windows preprocessor magic shadows JWindowManager's CreateWindow function.
+#undef CreateWindow
+#endif
 
 #include "common.h"
 
@@ -34,7 +41,7 @@
 #include "nfserver.h"
 #include "chat.h"
 
-#define SHIFT_DOWN_DEFAULT 15
+#define SHIFT_DOWN_DEFAULT 24
 #define SHIFT_RIGHT_DEFAULT 0
 
 extern int get_key_binding( char const *dir, int i );
@@ -43,14 +50,14 @@ int morph_sel_frame_color;
 
 view::~view()
 {
-  if (local_player())
-    sbar.associate(NULL);
+    if (local_player())
+        sbar.associate(NULL);
 
-  if (total_weapons)
-  {
-    free(weapons);
-    free(last_weapons);
-  }
+    if (total_weapons)
+    {
+        free(weapons);
+        free(last_weapons);
+    }
 }
 
 
@@ -115,72 +122,55 @@ int view::weapon_total(int type)
 
 int32_t view::xoff()
 {
-  if (focus)
-  {
-    int x=last_x-(cx2-cx1+1)/2+shift_right+pan_x;
-    if (x<0) return 0;
-    else return x;
-  } else return pan_x;
+    if (!m_focus)
+        return pan_x;
+
+    return Max(0, m_lastpos.x - (m_bb.x - m_aa.x + 1) / 2 + m_shift.x + pan_x);
 }
 
 int32_t view::interpolated_xoff()
 {
-  if (focus)
-  {
-    int x=(last_last_x+last_x)/2-(cx2-cx1+1)/2+shift_right+pan_x;
-    if (x<0) return 0;
-    else return x;
-  } else return pan_x;
-}
+    if (!m_focus)
+        return pan_x;
 
+    return Max(0, (m_lastlastpos.x + m_lastpos.x) / 2
+                    - (m_bb.x - m_aa.x + 1) / 2 + m_shift.x + pan_x);
+}
 
 int32_t view::yoff()
 {
-  if (focus)
-  {
-    int y=last_y-(cy2-cy1+1)/2-shift_down+pan_y;
-    if (y<0) return 0;
-    else return y;
-  } else return pan_y;
-}
+    if (!m_focus)
+        return pan_y;
 
+    return Max(0, m_lastpos.y - (m_bb.y - m_aa.y + 1) / 2 - m_shift.y + pan_y);
+}
 
 int32_t view::interpolated_yoff()
 {
-  if (focus)
-  {
-    int y=(last_y+last_last_y)/2-(cy2-cy1+1)/2-shift_down+pan_y;
-    if (y<0) return 0;
-    else return y;
-  } else return pan_y;
+    if (!m_focus)
+        return pan_y;
+
+    return Max(0, (m_lastlastpos.y + m_lastpos.y) / 2
+                    - (m_bb.y - m_aa.y + 1) / 2 - m_shift.y + pan_y);
 }
 
 
 void view::update_scroll()
 {
-  if (focus)
-  {
-    last_last_x=last_x;
-    last_last_y=last_y;
-    if (focus->x>last_x)
-    {
-      if (focus->x-last_x>=no_xright)
-        last_x=focus->x-no_xright;
-    } else if (focus->x<last_x)
-    {
-      if (last_x-focus->x>=no_xleft)
-        last_x=focus->x+no_xleft;
-    }
-    if (focus->y>last_y)
-    {
-      if (focus->y-last_y>=no_ybottom)
-        last_y=focus->y-no_ybottom;
-    } else if (focus->y<last_y)
-    {
-      if (last_y-focus->y>=no_ytop)
-        last_y=focus->y+no_ytop;
-    }
-  }
+    if (!m_focus)
+        return;
+
+    m_lastlastpos = m_lastpos;
+
+    if (m_focus->x > m_lastpos.x)
+        m_lastpos.x = Max(m_lastpos.x, m_focus->x - no_xright);
+    else if (m_focus->x < m_lastpos.x)
+        m_lastpos.x = Min(m_lastpos.x, m_focus->x + no_xleft);
+
+    if (m_focus->y > m_lastpos.y)
+        m_lastpos.y = Max(m_lastpos.y, m_focus->y - no_ybottom);
+    else if (m_focus->y < m_lastpos.y)
+        m_lastpos.y = Min(m_lastpos.y, m_focus->y + no_ytop);
 }
 
 static char cur_user_name[20] = { 0 };
@@ -193,6 +183,17 @@ char const *get_login()
 #if defined __CELLOS_LV2__
     /* FIXME: retrieve login name */
     return "Player";
+#elif defined WIN32
+	DWORD bufferSize = 120;
+	TCHAR *login;
+	login = (TCHAR*) malloc(bufferSize * sizeof(TCHAR));
+	if (GetUserName(login, &bufferSize))
+	{
+		return (char*) login;
+	} else
+	{
+		return "unknown";
+	}
 #else
     char const *login = getlogin();
     return login ? login : "unknown";
@@ -204,26 +205,16 @@ void set_login(char const *name)
     strncpy(cur_user_name, name, 20);
 }
 
-view::view(game_object *Focus, view *Next, int number)
+view::view(game_object *focus, view *Next, int number)
 {
-  chat_buf[0]=0;
+    m_chat_buf[0] = 0;
 
   draw_solid=-1;
   no_xleft=0;
   no_xright=0;
   no_ytop=0;
   no_ybottom=0;
-  if (Focus)
-  {
-    last_x=Focus->x;
-    last_y=Focus->y;
-  } else
-  {
-    last_x=last_y=0;
-  }
-
-  last_last_x=last_x;
-  last_last_y=last_y;
+    m_lastlastpos = m_lastpos = focus ? ivec2(focus->x, focus->y) : ivec2(0);
   last_hp=last_ammo=-1;
   last_type=-1;
   tsecrets=secrets=0;
@@ -242,14 +233,11 @@ view::view(game_object *Focus, view *Next, int number)
   god=0;
 
   player_number=number;
-  cx1=0;
-  cy1=0;
-  cx2=100;
-  cy2=100;
-  focus=Focus;
+    m_aa = ivec2(0);
+    m_bb = ivec2(100);
+    m_focus = focus;
   next=Next;
-  shift_down=SHIFT_DOWN_DEFAULT;
-  shift_right=SHIFT_RIGHT_DEFAULT;
+    m_shift = ivec2(SHIFT_RIGHT_DEFAULT, SHIFT_DOWN_DEFAULT);
   x_suggestion=0;
   y_suggestion=0;
   b1_suggestion=0;
@@ -283,31 +271,25 @@ view::view(game_object *Focus, view *Next, int number)
 
 int32_t view::x_center()
 {
-  if (!focus)
-    return (cx1+cx2)/2;
-  else
-    return focus->x;
+    return m_focus ? m_focus->x : (m_aa.x + m_bb.x) / 2;
 }
 
 int32_t view::y_center()
 {
-  if (!focus)
-    return (cy1+cy2)/2;
-  else
-    return focus->y;
+    return m_focus ? m_focus->y : (m_aa.y + m_bb.y) / 2;
 }
 
 void view::draw_character_damage()
 {
-  if (focus && drawable())
+  if (m_focus && drawable())
   {
-    if (last_hp!=focus->hp()) draw_hp();
+    if (last_hp!=m_focus->hp()) draw_hp();
     int i;
     for (i=0; i<total_weapons; i++)
       if (weapons[i]!=last_weapons[i])
       {
     last_weapons[i]=weapons[i];
-        sbar.draw_ammo(screen,i,weapons[i],current_weapon==i);
+        sbar.draw_ammo(main_screen,i,weapons[i],current_weapon==i);
       }
   }
 }
@@ -323,10 +305,10 @@ uint16_t make_sync()
     view *f=player_list;
     for (; f; f=f->next)
     {
-      if (f->focus)
+      if (f->m_focus)
       {
-    x^=(f->focus->x&0xffff);
-    x^=(f->focus->y&0xffff);
+    x^=(f->m_focus->x&0xffff);
+    x^=(f->m_focus->y&0xffff);
       }
     }
   }
@@ -340,7 +322,7 @@ uint16_t make_sync()
 void view::get_input()
 {
     int sug_x,sug_y,sug_b1,sug_b2,sug_b3,sug_b4;
-    int32_t sug_px,sug_py;
+    ivec2 sug_p(0, 0);
 
 // NOTE:(AK) I have commented this out so we don't use the lisp
 //        file "input.lsp" to get our key mappings.
@@ -381,19 +363,16 @@ void view::get_input()
     else*/
     {
         get_movement( 0, sug_x, sug_y, sug_b1, sug_b2, sug_b3, sug_b4 );
-        if( focus )
+        if( m_focus )
         {
-            the_game->mouse_to_game( last_demo_mx, last_demo_my, sug_px, sug_py, this );
-            if( last_demo_mbut & 1 )
+            sug_p = the_game->MouseToGame(last_demo_mpos);
+            if(last_demo_mbut & 1)
                 sug_b2 = 1;
-            if( last_demo_mbut & 2 )
+            if(last_demo_mbut & 2)
                 sug_b1 = 1;
         }
-        else
-            sug_px = sug_py = 0;
     }
 
-#if !defined __CELLOS_LV2__
     if( view_changed() )
     {
         base->packet.write_uint8( SCMD_VIEW_RESIZE );
@@ -405,8 +384,8 @@ void view::get_input()
 
         base->packet.write_uint32( suggest.pan_x );
         base->packet.write_uint32( suggest.pan_y );
-        base->packet.write_uint32( suggest.shift_down );
-        base->packet.write_uint32( suggest.shift_right );
+        base->packet.write_uint32( suggest.shift.y );
+        base->packet.write_uint32( suggest.shift.x );
     }
 
     if( weapon_changed() )
@@ -439,30 +418,29 @@ void view::get_input()
     if( sug_b4 )
         mflags |= 128;
 
-    base->packet.write_uint8( mflags );
-    base->packet.write_uint16((uint16_t)((int16_t)sug_px));
-    base->packet.write_uint16((uint16_t)((int16_t)sug_py));
-#endif
+    base->packet.write_uint8(mflags);
+    base->packet.write_uint16((uint16_t)sug_p.x);
+    base->packet.write_uint16((uint16_t)sug_p.y);
 }
 
 
 void view::add_chat_key(int key)  // return string if buf is complete
 {
-  int len=strlen(chat_buf);
+    int len = strlen(m_chat_buf);
   if (key==JK_BACKSPACE)
   {
     if (len)
     {
-      chat_buf[len-1]=0;
+      m_chat_buf[len-1]=0;
       if (local_player() && chat)
-        chat->draw_user(chat_buf);
+        chat->draw_user(m_chat_buf);
     }
   } else if (key!=JK_ENTER)
   {
-    chat_buf[len]=key;
-    chat_buf[len+1]=0;
+    m_chat_buf[len]=key;
+    m_chat_buf[len+1]=0;
     if (local_player() && chat)
-      chat->draw_user(chat_buf);
+      chat->draw_user(m_chat_buf);
   }
 
   if (len>38 || key==JK_ENTER)
@@ -470,30 +448,29 @@ void view::add_chat_key(int key)  // return string if buf is complete
     if (DEFINEDP(l_chat_input->GetFunction()))
     {
       game_object *o=current_object;
-      current_object=focus;
+      current_object=m_focus;
 
-      void *m=mark_heap(TMP_SPACE);
+      void *m = LSpace::Tmp.Mark();
       void *list=NULL;
-      push_onto_list(LString::Create(chat_buf),list);
+      push_onto_list(LString::Create(m_chat_buf),list);
       ((LSymbol *)l_chat_input)->EvalFunction(list);
-      restore_heap(m,TMP_SPACE);
+      LSpace::Tmp.Restore(m);
 
       current_object=o;
 
     } else
     {
       if (chat)
-        chat->put_all(chat_buf);
+        chat->put_all(m_chat_buf);
     }
-    chat_buf[0]=0;
+    m_chat_buf[0]=0;
     if (local_player() && chat)
-      chat->draw_user(chat_buf);
+      chat->draw_user(m_chat_buf);
   }
 }
 
 int view::process_input(char cmd, uint8_t *&pk)   // return 0 if something went wrong
 {
-#if !defined __CELLOS_LV2__
   switch (cmd)
   {
     case SCMD_CHAT_KEYPRESS :
@@ -504,19 +481,14 @@ int view::process_input(char cmd, uint8_t *&pk)   // return 0 if something went
     {
       int32_t x[8];
       memcpy(x,pk,8*4);  pk+=8*4;
-      cx1=lltl(x[0]);
-      cy1=lltl(x[1]);
-      cx2=lltl(x[2]);
-      cy2=lltl(x[3]);
+      m_aa = ivec2(lltl(x[0]), lltl(x[1]));
+      m_bb = ivec2(lltl(x[2]), lltl(x[3]));
 
       pan_x=lltl(x[4]);
       pan_y=lltl(x[5]);
-      shift_down=lltl(x[6]);
-      shift_right=lltl(x[7]);
+      m_shift = ivec2(lltl(x[7]), lltl(x[6]));
       if (small_render)
-      {
-        small_render->Scale(vec2i(cx2 - cx1 + 1, cy2 - cy1 + 1));
-      }
+          small_render->Scale(m_bb - m_aa + ivec2(1));
 
       suggest.send_view=0;
       if (local_player())
@@ -565,17 +537,12 @@ int view::process_input(char cmd, uint8_t *&pk)   // return 0 if something went
     case SCMD_KEYRELEASE : set_key_down(*(pk++),0); break;
     case SCMD_EXT_KEYRELEASE : set_key_down(*(pk++)+256,0); break;
   }
-#endif
   return 1;
 }
 
 int view::local_player()
 {
-#if defined __CELLOS_LV2__
-  return 1;
-#else
   return player_number==client_number();
-#endif
 }
 
 void view::next_weapon()
@@ -636,7 +603,7 @@ void view::last_weapon()
 
 }
 
-int view::handle_event(event &ev)
+int view::handle_event(Event &ev)
 {
     if( ev.type == EV_KEY )
     {
@@ -716,15 +683,15 @@ int view::handle_event(event &ev)
 
 void view::draw_hp()
 {
-    if (focus)
+    if (m_focus)
     {
-        int h = focus->hp();
+        int h = m_focus->hp();
         last_hp=h;
-        sbar.draw_health( screen, focus->hp() );
+        sbar.draw_health( main_screen, m_focus->hp() );
     }
     else
     {
-        sbar.draw_health( screen, 0 );
+        sbar.draw_health( main_screen, 0 );
     }
 }
 
@@ -737,7 +704,7 @@ int view::drawable()
 void recalc_local_view_space()   // calculates view areas for local players, should be called
                                  // when adding or deleting local players
 {
-  if (screen)
+  if (main_screen)
   {
     int t=total_local_players();
     if (!t) return ;
@@ -761,19 +728,16 @@ void recalc_local_view_space()   // calculates view areas for local players, sho
     f->suggest.cy1=y;
     f->suggest.cy2=h-(total_weapons ? 33 : 0);
 
-    f->suggest.shift_down=f->shift_down;
-    f->suggest.shift_right=f->shift_right;
+    f->suggest.shift = f->m_shift;
     f->suggest.pan_x=f->pan_x;
     f->suggest.pan_y=f->pan_y;
     f->suggest.send_view=1;
 
     if (!player_list->next)
     {
-      f->cx1=f->suggest.cx1;
-      f->cy1=f->suggest.cy1;
-      f->cx2=f->suggest.cx2;
-      f->cy2=f->suggest.cy2;
-      f->suggest.send_view=0;
+      f->m_aa = ivec2(f->suggest.cx1, f->suggest.cy1);
+      f->m_bb = ivec2(f->suggest.cx2, f->suggest.cy2);
+      f->suggest.send_view = 0;
     }
     y+=h;
       }
@@ -826,8 +790,9 @@ void set_local_players(int total)
       f->next=new view(o,NULL,f->player_number+1);
       v=f->next;
     }
-    v->cx1=320/2-155; v->cy1=200/2-95; v->cx2=320/2+155; v->cy2=200/2+(total_weapons ? 60 : 95);
-    v->focus->set_controller(v);
+    v->m_aa = ivec2(320 / 2 - 155, 200 / 2 - 95);
+    v->m_bb = ivec2(320 / 2 + 155, 200 / 2 + total_weapons ? 60 : 95);
+    v->m_focus->set_controller(v);
     total--;
     rdw=1;
   }
@@ -844,19 +809,6 @@ int total_local_players()
   return t;
 }
 
-
-void view::resize_view(int32_t Cx1, int32_t Cy1, int32_t Cx2, int32_t Cy2)
-{
-  if (cx1!=Cx1 || cx2!=Cx2 || cy1!=Cy1 || cy2!=Cy2)
-  {
-    cx1=Cx1; cy1=Cy1;
-    cx2=Cx2; cy2=Cy2;
-    if (playing_state(the_game->state) && local_player())
-      the_game->draw(0);
-  }
-}
-
-
 void view::set_input(int cx, int cy, int b1, int b2, int b3, int b4, int px, int py)
 {
     x_suggestion=cx;
@@ -873,45 +825,44 @@ void view::set_input(int cx, int cy, int b1, int b2, int b3, int b4, int px, int
 
 void view::reset_player()
 {
-  if (focus)
+  if (m_focus)
   {
 
-    game_object *start=current_level ? current_level->get_random_start(320,focus->controller()) : 0;
-    focus->defaults();
+    game_object *start=current_level ? current_level->get_random_start(320,m_focus->controller()) : 0;
+    m_focus->defaults();
     if (start)
     {
-      focus->x=start->x;
-      focus->y=start->y;
+      m_focus->x=start->x;
+      m_focus->y=start->y;
       dprintf("reset player position to %d %d\n",start->x,start->y);
     }
-    focus->set_state(stopped);
-    focus->set_tint(_tint);
-    focus->set_team(_team);
+    m_focus->set_state(stopped);
+    m_focus->set_tint(_tint);
+    m_focus->set_team(_team);
     memset(weapons,0xff,total_weapons*sizeof(int32_t));
     memset(last_weapons,0xff,total_weapons*sizeof(int32_t));
 
-    shift_down=SHIFT_DOWN_DEFAULT;
-    shift_right=SHIFT_RIGHT_DEFAULT;
+    m_shift = ivec2(SHIFT_RIGHT_DEFAULT, SHIFT_DOWN_DEFAULT);
 
     if (total_weapons)
       weapons[0]=0;  // give him the first weapon
     current_weapon=0;
 
-    memset(focus->lvars,0,figures[focus->otype]->tv*4);
-    focus->set_aistate(0);
-    if (figures[focus->otype]->get_fun(OFUN_CONSTRUCTOR))
+    memset(m_focus->lvars,0,figures[m_focus->otype]->tv*4);
+    m_focus->set_aistate(0);
+    if (figures[m_focus->otype]->get_fun(OFUN_CONSTRUCTOR))
     {
       game_object *o=current_object;
-      current_object=focus;
-      ((LSymbol *)figures[focus->otype]->get_fun(OFUN_CONSTRUCTOR))->EvalUserFunction(NULL);
+      current_object=m_focus;
+      ((LSymbol *)figures[m_focus->otype]->get_fun(OFUN_CONSTRUCTOR))->EvalUserFunction(NULL);
       current_object=o;
     }
-    sbar.redraw(screen);
+    sbar.redraw(main_screen);
 
     int i;
-    for (i=0; i<focus->total_objects(); i++)   // reset the vars for the attached objects
+    for (i=0; i<m_focus->total_objects(); i++)   // reset the vars for the attached objects
     {
-      game_object *o=focus->get_object(i);
+      game_object *o=m_focus->get_object(i);
       memset(o->lvars,0,figures[o->otype]->tv*4);
     }
 
@@ -927,19 +878,19 @@ object_node *make_player_onodes(int player_num)
   object_node *first=NULL,*last=NULL;
   for (view *o=player_list; o; o=o->next)
   {
-    if (o->focus && (player_num==-1 || o->player_number==player_num))
+    if (o->m_focus && (player_num==-1 || o->player_number==player_num))
     {
-      if (!object_to_number_in_list(o->focus,first))
+      if (!object_to_number_in_list(o->m_focus,first))
       {
-    object_node *q=new object_node(o->focus,NULL);
+    object_node *q=new object_node(o->m_focus,NULL);
     if (first)
       last->next=q;
     else first=q;
     last=q;
       }
-      for (int i=0; i<o->focus->total_objects(); i++)
+      for (int i=0; i<o->m_focus->total_objects(); i++)
       {
-    game_object *p=o->focus->get_object(i);
+    game_object *p=o->m_focus->get_object(i);
 
     if (!object_to_number_in_list(p,first))
     {
@@ -1014,12 +965,12 @@ int32_t view::get_view_var_value(int num)
 {
   switch (num)
   {
-    case V_CX1 : return cx1; break;
-    case V_CY1 : return cy1; break;
-    case V_CX2 : return cx2; break;
-    case V_CY2 : return cy2; break;
-    case V_SHIFT_DOWN : return shift_down; break;
-    case V_SHIFT_RIGHT : return shift_right; break;
+    case V_CX1 : return m_aa.x; break;
+    case V_CY1 : return m_aa.y; break;
+    case V_CX2 : return m_bb.x; break;
+    case V_CY2 : return m_bb.y; break;
+    case V_SHIFT_DOWN : return m_shift.y; break;
+    case V_SHIFT_RIGHT : return m_shift.x; break;
     case V_GOD : return god; break;
     case V_PLAYER_NUMBER : return player_number; break;
 
@@ -1038,8 +989,8 @@ int32_t view::get_view_var_value(int num)
     case V_NO_XRIGHT : return no_xright; break;
     case V_NO_YTOP : return no_ytop; break;
     case V_NO_YBOTTOM : return no_ybottom; break;
-    case V_LAST_X : return last_x; break;
-    case V_LAST_Y : return last_y; break;
+    case V_LAST_X : return m_lastpos.x; break;
+    case V_LAST_Y : return m_lastpos.y; break;
     case V_LAST_LEFT : return last_left; break;
     case V_LAST_RIGHT : return last_right; break;
     case V_LAST_UP : return last_up; break;
@@ -1056,8 +1007,8 @@ int32_t view::get_view_var_value(int num)
     case V_AMBIENT : return ambient; break;
     case V_POINTER_X : return pointer_x; break;
     case V_POINTER_Y : return pointer_y; break;
-    case V_LAST_LAST_X : return last_last_x; break;
-    case V_LAST_LAST_Y : return last_last_y; break;
+    case V_LAST_LAST_X : return m_lastlastpos.x; break;
+    case V_LAST_LAST_Y : return m_lastlastpos.y; break;
     case V_FREEZE_TIME : return freeze_time; break;
   }
   return 0;
@@ -1069,12 +1020,12 @@ int32_t view::set_view_var_value(int num, int32_t x)
 {
   switch (num)
   {
-    case V_CX1 : cx1=x; break;
-    case V_CY1 : cy1=x; break;
-    case V_CX2 : cx2=x; break;
-    case V_CY2 : cy2=x; break;
-    case V_SHIFT_DOWN : shift_down=x; break;
-    case V_SHIFT_RIGHT : shift_right=x; break;
+    case V_CX1 : m_aa.x = x; break;
+    case V_CY1 : m_aa.y = x; break;
+    case V_CX2 : m_bb.x = x; break;
+    case V_CY2 : m_bb.y = x; break;
+    case V_SHIFT_DOWN : m_shift.y = x; break;
+    case V_SHIFT_RIGHT : m_shift.x = x; break;
     case V_GOD : god=x; break;
     case V_PLAYER_NUMBER : { player_number=x; if (local_player()) sbar.associate(this); }  break;
 
@@ -1093,8 +1044,8 @@ int32_t view::set_view_var_value(int num, int32_t x)
     case V_NO_XRIGHT : no_xright=x; break;
     case V_NO_YTOP : no_ytop=x; break;
     case V_NO_YBOTTOM : no_ybottom=x; break;
-    case V_LAST_X : last_x=x; break;
-    case V_LAST_Y : last_y=x; break;
+    case V_LAST_X : m_lastpos.x=x; break;
+    case V_LAST_Y : m_lastpos.y=x; break;
     case V_LAST_LEFT : last_left=x; break;
     case V_LAST_RIGHT : last_right=x; break;
     case V_LAST_UP : last_up=x; break;
@@ -1112,8 +1063,8 @@ int32_t view::set_view_var_value(int num, int32_t x)
     case V_AMBIENT : ambient=x; break;
     case V_POINTER_X : pointer_x=x; break;
     case V_POINTER_Y : pointer_y=x; break;
-    case V_LAST_LAST_X : last_last_x=x; break;
-    case V_LAST_LAST_Y : last_last_y=x; break;
+    case V_LAST_LAST_X : m_lastlastpos.x = x; break;
+    case V_LAST_LAST_Y : m_lastlastpos.y = x; break;
     case V_FREEZE_TIME : freeze_time=x; break;
   }
   return 1;
@@ -1177,7 +1128,6 @@ void view::configure_for_area(area_controller *a)
 
 void process_packet_commands(uint8_t *pk, int size)
 {
-#if !defined __CELLOS_LV2__
   int32_t sync_uint16=-1;
 
   if (!size) return ;
@@ -1264,7 +1214,7 @@ void process_packet_commands(uint8_t *pk, int size)
         delete last;
       }
 
-      v->focus=NULL;
+      v->m_focus=NULL;
       if (last)
       last->next=v->next;
       else player_list=player_list->next;
@@ -1277,7 +1227,6 @@ void process_packet_commands(uint8_t *pk, int size)
 
     }
   } while (cmd!=SCMD_END_OF_PACKET);
-#endif
 }
 
 void view::set_tint(int tint)
@@ -1285,7 +1234,7 @@ void view::set_tint(int tint)
     if(tint < 0)
         tint = 0;
     _tint = tint;
-    focus->set_tint(tint);
+    m_focus->set_tint(tint);
 }
 
 int view::get_tint()
@@ -1298,7 +1247,7 @@ void view::set_team(int team)
     if(team < 0)
         team = 0;
     _team = team;
-    focus->set_team(team);
+    m_focus->set_team(team);
 }
 
 int view::get_team()
